@@ -5,6 +5,15 @@
 # @File    : __init__.py.py
 
 
+from Utils import package
+
+pk_lst = [
+    'pymongo==3.6.0',
+    'pika==1.2.0',
+    'redis==4.1.4',
+]
+package(pk_lst)
+
 from .mongo_conn import MongoPerson
 from .rabbit_conn import RabbitClient, MonitorRabbit
 from .redis_conn import ReidsClient
